/* XPM */

/** \file gerbv_icon.h
    \brief Contains the xpm data for the gerbv application icon
    \ingroup gerbv
*/

#define USE_NEW_ICON

#ifdef USE_NEW_ICON
/* This is the new icon */
static char *gerbv_icon_xpm[] = {
/* columns rows colors chars-per-pixel */
"48 48 104 2",
"   c #000000",
".  c #050709",
"X  c #070808",
"o  c #090A0A",
"O  c #0E0F10",
"+  c #121313",
"@  c #151618",
"#  c #13181C",
"$  c #191B1C",
"%  c #151C23",
"&  c #191C20",
"*  c #1E2124",
"=  c #19232E",
"-  c #1F2C3A",
";  c #232425",
":  c #222628",
">  c #24292B",
",  c #2A2B2C",
"<  c #292F31",
"1  c #22303F",
"2  c #2D3335",
"3  c #343434",
"4  c #3B3B3B",
"5  c #273544",
"6  c #293746",
"7  c #2D3B4A",
"8  c #323940",
"9  c #333E4B",
"0  c #434343",
"q  c #4B4B4B",
"w  c #495057",
"e  c #49525B",
"r  c #535353",
"t  c #50575E",
"y  c #5A5A5A",
"u  c #4D5966",
"i  c #515F6E",
"p  c #56626F",
"a  c #596067",
"s  c #5C6671",
"d  c #5D6B7A",
"f  c #636363",
"g  c #61686F",
"h  c #6B6B6B",
"j  c #646B72",
"k  c #616F7E",
"l  c #62707F",
"z  c #737373",
"x  c #7D7D7D",
"c  c #657382",
"v  c #697786",
"b  c #6D7986",
"n  c #6D7B8A",
"m  c #717F8E",
"M  c #74808E",
"N  c #748392",
"B  c #798593",
"V  c #7E8C9B",
"C  c #848484",
"Z  c #8A8A8A",
"A  c #81909F",
"S  c #949494",
"D  c #9A9A9A",
"F  c #8392A1",
"G  c #8896A5",
"H  c #8D9BAA",
"J  c #919DAB",
"K  c #92A0AE",
"L  c #94A2B1",
"P  c #99A6B5",
"I  c #9AA8B7",
"U  c #9CAABA",
"Y  c #A3A3A3",
"T  c gray67",
"R  c #A0AEBD",
"E  c #A2B0BF",
"W  c #B3B3B3",
"Q  c gray74",
"!  c #A4B3C2",
"~  c #A8B6C5",
"^  c #AAB8C7",
"/  c #ADBBCA",
"(  c #B1BFCE",
")  c #B3C0CF",
"_  c #B4C2D1",
"`  c #B8C6D5",
"'  c #BAC8D7",
"]  c #BCCAD9",
"[  c #C2C2C2",
"{  c #CBCBCB",
"}  c #C1CFDE",
"|  c #D3D3D3",
" . c #DBDBDB",
".. c #C4D3E2",
"X. c #C8D6E5",
"o. c #CCDAEA",
"O. c #D0DEED",
"+. c #D2E0EF",
"@. c #D2E1F0",
"#. c #E3E3E3",
"$. c #ECECEC",
"%. c #F3F3F3",
"&. c #FEFEFE",
"*. c None",
/* pixels */
"*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.*.r q q q 0 0 *.*.*.*.0 q q q *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.0 f &.#.[ C q q q 0 0 q #. .f q 0 *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.0 Y &.&.&.&.&.%.{ D y r C Y  .| y q 0 *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.r | &.&.[ T %.&.&.&.$.%. .T z q z C r q 0 *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.q %.&.&.S ; X , f D  .&.&.&.$.%.#.Q C q q 0 0 4 *.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.q y &.&.&.D { $.D y $ S &.&.&.#.Q [ %.&.&.$.[ C r q 0 4 4 *.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.0 S &.&.T X X o , C Q +  .&.0 z %. .T W $.&.&.&.%.#.{ D y 0 0 4 4 *.*.*.*.*.*.*.*.",
"*.*.q 0 0 0 q 0 0 0 0 0 0 0 0 0 0 0 4 0 0 0 0 0 0 0 0 0 0 4 0 4 0 Z  .%.&. .Y 0 4 *.*.*.*.*.*.*.",
"*.*.q &.&.&.&.%.&.&.&.$.$.$.$.$.$.$.&.$.%.&.%.$.&.%.$.&.&.&.&.&.%.0 &.| { $.&.0 4 *.*.*.*.*.*.*.",
"*.*.0 &.&.&.&. .&.&.&.| | | | | | | &. .#.$.$.| #.%. . .&.&.$.$.%.4 &.&.&. . .0 *.*.*.*.*.*.*.*.",
"*.*.q &.&.&.D C C C C Z Q | { T Q | &.T | $.$. .$.$.Q | %.&.%. .%.4 $.&.&.&.| r q 4 *.*.*.*.*.*.",
"*.*.0 &.&.&.$.%.&.&.$.[ Z Q | Q Z [ $.[ Z | $.| $.$.C | %.&.&. .&.4 W &.&.&.D W  .h 0 0 *.*.*.*.",
"*.*.0 &.&.&.Z C C C C Q ( Z Q | Q Z {  .| S {  .$.%.C | &.&.&.| &.4 Y %.&.&.y  .&.&.| y 0 0 *.*.",
"*.*.0 &.&.&.C C C C C C Q Q Z | | { Z #.$.| Z  .$.&.C #.&.&.$. .&.4 [ | &.%.q $.&.&.&.&.{ r 0 0 ",
"*.*.0 &.&.%.C C C C C C C | C { |  .C  .#.$.C #.%.&.C $.&.&. .$.&.4  .Q &. .h q z &.&.&.&.&.W 0 ",
"*.*.0 &.&.%.C C C C C C C | C | |  .C #. .| C  .$.$.C %.&.&.| %.&.4 Q { &.T x o #.&.&.&.&.&.$.0 ",
"*.*.0 &.&.#.C C C C C C C { C | | { f x q q 0 T | | C  .$.$.| &.&.4 T &.&.h 4 f &.&.&.&.&.&.C 4 ",
"*.*.0 &.&.#.C C C C C C C | C Q 0       $ @       0 z #. . .| %.&.4 | &.&.0 + %.&.&.&.&.&.$.0 4 ",
"*.*.0 &.%.#.C C C C C C C | r O o i s ) ..( m J j X X Y $. . .| &.4 &.&. .0 z &.&.&.&.&.&.z 4 *.",
"*.*.0 &.$.$.C C C C C C C 4   * b V A V A V A V V b *   r |  .| %.3 &.&.W > &.&.&.&.&.&. .0 4 *.",
"*.*.0 &.#.&.x r 0 3 3 , ;   2 _ X...V ..X.] V X...( V w   C #. .%.4 | &.h h &.&.&.&.&.&.f 4 *.*.",
"*.*.4 &. .&.X             # 1 v ] H n ~ X.~ V / +.! V ! * o { | &.3 Q $.4 $.&.&.&.&.&. .0 *.*.*.",
"*.*.0 &.[ &.              u 1 c / n 1 N ..L n ~ @.^ V ! b o 0 [ &.4 &.| 4 { &.&.&.&.&.r 4 *.*.*.",
"*.*.0 &.| &.            # c 1 v K n 1 m ( V 5 V @.U d I i j   Q &.3 { T 0 h &.&.&.&.{ 0 *.*.*.*.",
"*.*.4 %.$.&.            = H v U K ~ V E K ~ K ] ( o.K o.1 K   T &.4 | z 4 C &.&.&.&.r 4 *.*.*.*.",
"*.*.0 %.&.&.            - K I L K ' ] U K ` +.E K ] +.] 1 '   C &.3 $.0 + #.&.&.&.[ 4 *.*.*.*.*.",
"*.*.0 %.&.&.          . 1 K L U ~ ] ] K L o.O.K K } +.P 1 ` + r &.4 $.4 f &.&.&.&.q 4 *.*.*.*.*.",
"*.*.4 %.&.%.          . 1 E V H L R N K ' o.H H I X.G H 1 ( + r &.3 { , $.&.&.&.W 4 *.*.*.*.*.*.",
"*.*.4 &.&.$.            - M 1 c o.m 1 k L c 1 k ' V 5 d 1 H   C &.3 Z y &.&.&.&.0 3 *.*.*.*.*.*.",
"*.*.4 &.&.&.            = d 5 n ] m 1 k o.v 1 d L d 5 c 1 M   Y &.3 q { &.&.&.T 4 *.*.*.*.*.*.*.",
"*.*.4 &.&.&.            # N - V +.F 1 n +.F 1 k ' B - i 5 ; . y #.3 4 &.&.&.%.4 4 *.*.*.*.*.*.*.",
"*.*.4 %.$.%.              p 5 o.O.o.1 X.+.] 1 ! / ' c 5 9 X : $ o + y &.&.&.D 4 *.*.*.*.*.*.*.*.",
"*.*.4 &.| [               & 5 - 1 1 1 1 1 1 1 1 5 - 6 i . @ 2 2 2 # X 4 [ %.4 4 *.*.*.*.*.*.*.*.",
"*.*.4 &.&.&.o         X h   % o.@.@.1 @.+.+.7 E O.' ! e   X $ < 2 2 2 * o ; ; *.*.*.*.*.*.*.*.*.",
"*.*.4 &.&.&.&.&.&.&.&.$.S     < P } 1 @.@.@.^ 9 ! _ <   y { f o $ , 2 2 2 * X     *.*.*.*.*.*.*.",
"*.*.4 &.&.&.f           o T Z o X t e L _ ..' B %           x $.x X @ : 2 2 < ; .       *.*.*.*.",
"*.*.4 &.&.&.&.&.&.&.&.&.&.&.&. .3       + @       0 | &.&.%.%.&.%.2 x + O : 2 2 2 : o     *.*.*.",
"*.*.4 &.&.&.&.&.&.&.&.&.&.&.&.&.&.$.Y h 4 4 f Y  . .{ Q [  .#.$.%.3 &.z + . o * 2 2 2 : X   *.*.",
"*.*.4 &.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.%.&.&.&.&.%.%.%.$.4  .4 3       X ; 2 2 @   *.*.",
"*.*.0 4 4 4 4 3 4 4 3 4 4 3 4 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 Z f 3 *.*.*.*.    . @     *.*.",
"*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.3 4 q { &.&.&. .4 *.*.*.*.*.*.*.      *.*.*.",
"*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.3 3 r | &.r 3 *.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.3 4 3 4 *.*.*.*.*.*.*.*.*.*.*.*.*.*.",
"*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.*.2 *.*.*.*.*.*.*.*.*.*.*.*.*.*.*."
};

#else 

/* This is the old icon.  To get it back, just rename it. */
static char * gerbv_icon_xpm[] = {
"48 48 244 2",
"  	c None",
". 	c #1F8888",
"+ 	c #000000",
"@ 	c #2CC2C2",
"# 	c #37F2F2",
"$ 	c #000200",
"% 	c #010401",
"& 	c #39FEFE",
"* 	c #040D03",
"= 	c #071505",
"- 	c #081806",
"; 	c #3AFFFF",
"> 	c #030902",
", 	c #061505",
"' 	c #0B2308",
") 	c #0F300B",
"! 	c #12380D",
"~ 	c #1D8383",
"{ 	c #2BC0C0",
"] 	c #2AB9B9",
"^ 	c #155E5E",
"/ 	c #051717",
"( 	c #040F03",
"_ 	c #0C2709",
": 	c #174811",
"< 	c #236C1A",
"[ 	c #2C8721",
"} 	c #309424",
"| 	c #020802",
"1 	c #081A06",
"2 	c #12370D",
"3 	c #206318",
"4 	c #2D8C22",
"5 	c #35A328",
"6 	c #37AA29",
"7 	c #39AF2B",
"8 	c #38AD2A",
"9 	c #339D26",
"0 	c #1D5A16",
"a 	c #051204",
"b 	c #0A1F07",
"c 	c #154310",
"d 	c #26741C",
"e 	c #329B26",
"f 	c #38AC2A",
"g 	c #1D5916",
"h 	c #0A2008",
"i 	c #174611",
"j 	c #27781D",
"k 	c #339F27",
"l 	c #051104",
"m 	c #091E07",
"n 	c #143F0F",
"o 	c #236D1A",
"p 	c #309624",
"q 	c #37A929",
"r 	c #38AE2A",
"s 	c #020601",
"t 	c #1C5715",
"u 	c #297F1F",
"v 	c #329925",
"w 	c #35A428",
"x 	c #030A02",
"y 	c #133A0E",
"z 	c #1D5B16",
"A 	c #26761D",
"B 	c #2B8520",
"C 	c #39FCFC",
"D 	c #061405",
"E 	c #0D2809",
"F 	c #15400F",
"G 	c #1C5615",
"H 	c #1F6117",
"I 	c #35EAEA",
"J 	c #061204",
"K 	c #133D0F",
"L 	c #1A5114",
"M 	c #2ECBCB",
"N 	c #081B06",
"O 	c #10320C",
"P 	c #1B5314",
"Q 	c #236E1B",
"R 	c #287B1E",
"S 	c #37F4F4",
"T 	c #29B6B6",
"U 	c #135656",
"V 	c #0E2B0A",
"W 	c #194F13",
"X 	c #2F9123",
"Y 	c #000202",
"Z 	c #133B0E",
"` 	c #226919",
" .	c #36A628",
"..	c #000101",
"+.	c #0A1E07",
"@.	c #164410",
"#.	c #216819",
"$.	c #2F9023",
"%.	c #37AB2A",
"&.	c #329C26",
"*.	c #184912",
"=.	c #2F9224",
"-.	c #2E8E23",
";.	c #010501",
">.	c #040E03",
",.	c #0D2A0A",
"'.	c #12390E",
").	c #154210",
"!.	c #1C5815",
"~.	c #000100",
"{.	c #030B05",
"].	c #020701",
"^.	c #051004",
"/.	c #050F03",
"(.	c #010505",
"_.	c #DD1313",
":.	c #EA1414",
"<.	c #E41313",
"[.	c #DF1313",
"}.	c #B80F0F",
"|.	c #460606",
"1.	c #9F0D0D",
"2.	c #FF1616",
"3.	c #F81515",
"4.	c #E21313",
"5.	c #DE1313",
"6.	c #A10E0E",
"7.	c #B10F0F",
"8.	c #F91515",
"9.	c #B51010",
"0.	c #B91010",
"a.	c #F01414",
"b.	c #F11515",
"c.	c #E11313",
"d.	c #EE1414",
"e.	c #C81111",
"f.	c #F31515",
"g.	c #ED1414",
"h.	c #D11212",
"i.	c #B11010",
"j.	c #3D0B0B",
"k.	c #D21313",
"l.	c #D91313",
"m.	c #A70F0F",
"n.	c #E91414",
"o.	c #F71515",
"p.	c #F61515",
"q.	c #A91010",
"r.	c #090909",
"s.	c #B81010",
"t.	c #DA1313",
"u.	c #DB1313",
"v.	c #9F0F0F",
"w.	c #EF1515",
"x.	c #820D0D",
"y.	c #9F1010",
"z.	c #0A0A0A",
"A.	c #C11212",
"B.	c #E51414",
"C.	c #B41010",
"D.	c #840F0F",
"E.	c #F51515",
"F.	c #810D0D",
"G.	c #950F0F",
"H.	c #E71414",
"I.	c #D61313",
"J.	c #901010",
"K.	c #C81313",
"L.	c #7B1111",
"M.	c #DE1414",
"N.	c #A01010",
"O.	c #EC1414",
"P.	c #F11414",
"Q.	c #991010",
"R.	c #E41414",
"S.	c #931010",
"T.	c #DD1414",
"U.	c #C41212",
"V.	c #0B0B0B",
"W.	c #8A1010",
"X.	c #0E0E0E",
"Y.	c #7A1111",
"Z.	c #450C0C",
"`.	c #490C0C",
" +	c #880E0E",
".+	c #400C0C",
"++	c #E31414",
"@+	c #E11414",
"#+	c #821111",
"$+	c #7F1111",
"%+	c #801111",
"&+	c #831111",
"*+	c #851111",
"=+	c #3E0E0E",
"-+	c #D71414",
";+	c #0C0C0C",
">+	c #8E1010",
",+	c #791111",
"'+	c #BD1313",
")+	c #BF1313",
"!+	c #D31414",
"~+	c #6C0F0F",
"{+	c #AB1111",
"]+	c #EE1515",
"^+	c #941212",
"/+	c #0F0F0F",
"(+	c #0D0D0D",
"_+	c #611010",
":+	c #3D0E0E",
"<+	c #D51414",
"[+	c #881111",
"}+	c #370E0E",
"|+	c #B31212",
"1+	c #A51111",
"2+	c #E01414",
"3+	c #A51212",
"4+	c #861111",
"5+	c #380E0E",
"6+	c #891111",
"7+	c #D61414",
"8+	c #8B1111",
"9+	c #AC1010",
"0+	c #390D0D",
"a+	c #D51313",
"b+	c #840E0E",
"c+	c #AF1212",
"d+	c #871010",
"e+	c #3A0D0D",
"f+	c #5C1010",
"g+	c #B01313",
"h+	c #C81414",
"i+	c #C91414",
"j+	c #CC1414",
"k+	c #400E0E",
"l+	c #D81414",
"m+	c #6F0F0F",
"n+	c #E21414",
"o+	c #AF1111",
"p+	c #A11111",
"q+	c #CB1313",
"r+	c #B51212",
"s+	c #610F0F",
"t+	c #9A1010",
"u+	c #A41111",
"                                                                                                ",
"                                                                                                ",
"                                                                                                ",
"                                                                                                ",
"                                                                      .                         ",
"            + + + + + + + + + + + + + + + + + + + + + + + + + + + + + @ + + + + +               ",
"            + + + + + + + + + + + + + + + + + + + + + + + + + + + + + # + + + + + +             ",
"            + + + + + + + + + + + + + + $ % % % % $ + + + + + + + + + & + + + + + +             ",
"            + + + + + + + + + + + + $ % * = - - = * % $ + + + + + + + ; + + + + + +             ",
"            + + + + + + + + + + + $ > , ' ) ! ! ) ' , > $ + + + + + + ; + + + + + + +           ",
"          ~ { # & ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; & # ] ^ /           ",
"          + + + + + + + + + + + $ ( _ : < [ } } [ < : _ ( $ + + + + + ; + + + + + + +           ",
"          + + + + + + + + + + + | 1 2 3 4 5 6 6 5 4 3 2 1 | + + + + 7 ; 7 7 8 9 0 a + +         ",
"          + + + + + + + + + + + > b c d e f 7 7 7 7 7 7 7 7 7 7 7 7 7 ; 7 7 8 9 g a + +         ",
"          + + + + + + + + + + + > h i j k f 7 7 7 7 7 7 7 7 7 7 7 7 7 ; 7 7 8 9 g l + +         ",
"          + + + + + + + + + + + > m n o p q r 7 7 7 7 7 7 7 7 7 7 7 7 ; + + + + + + + +         ",
"          + + + + + + + + + + + s = ) t u v w w v u t ) = s + + + + + ; + + + + + + + +         ",
"          + + + + + + + + + + + + x b y z A B B A z y b x + + + + + + C + + + + + + + +         ",
"          + + # + ; + ; + ; + + + % D E F G H H G F E D % + + + + + + I + + + + + + + +         ",
"          + + + + + + + + + + + + % J _ K L z z L K _ J % + + + + + + M + + + + + + + +         ",
"          + + # + ; + ; + ; + + + x N O P Q R R Q P O N x + + + + + + ] S ; & # T U + +         ",
"          + + + + + + + + + + + % l V W A X 9 9 X A W V l % + + Y + + + + + + + + + + +         ",
"          + + + + + + ; + ; + + | N Z ` X  .f f  .X ` Z N | + + ..+ + + + + + + + + + +         ",
"          + + + + + + + + + + + | +.@.A 9 f 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 + + + + + +         ",
"          + + + + + + ; + ; + + | +.@.A 9 f 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 7 8 + + + + +         ",
"          + + + + + + + + + + + | N Z #.$. .%.%.r r 8 8 8 8 8 8 8 8 8 8 8 8 f &.+ + + +         ",
"            + + + + + # + # + + % l _ *.< B =.=.B < *._ l % + + + + + + 9 9 &.-.+ + + +         ",
"            + + + + + + + + + + + ;.>.1 ,.'.).).'.,.1 >.;.+ + + + + + + !.!.!.L + + +           ",
"              + + + + + + + + + + + ~.$ % s {.].s % $ ~.+ + + + + + + + + ^.^./.+ + +           ",
"                + + + + + + + + + + + + + (...+ + + + + + + + + + + + + + + + + + + +           ",
"                  + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +             ",
"                      + + + + + + + + + + + + + + + + + + + + + + + + + + + +                   ",
"            _.:.<.[.}.|.                                1.2.2.                                  ",
"          2.2.3.4.5.2.6.                                7.2.2.                                  ",
"        8.2.9.                                          0.2.2.                                  ",
"      a.2.b.                c.d.d.e.      <.f.    d.g.h.i.2.2.j.k.l.m.    a.n.        o.        ",
"      p.2.q.  r.          2.b.s.t.2.u.    d.2.8.2.2.2.c.v.2.2.w.2.2.2.x.  2.2.5.      3.        ",
"      f.2.y.z.z.  A.B.C.2.o.D.    2.E.F.  B.2.2.t.G.H.I.J.2.2.K.L.M.2.B.  N.2.O.    b.c.        ",
"      P.2.Q.z.z.  R.2.R.2.2.2.2.2.2.2.S.  T.2.U.V.V.V.V.W.2.2.X.X.Y.2.2.V.z.2.2.Z.`.2. +        ",
"      5.2.2..+z.  ++2.M.2.@+#+$+%+&+*+=+V.-+2.W.;+;+V.z.>+2.2.X.X.,+2.2.;+V.k.2.'+)+f.          ",
"        w.2.!+~+  M.2.{+2.]+^+/+X.(+_+:+;+<+2.[+;+V.z.  Q.2.2.}+(+K.2.|+;+V.1+2.2.2+3+V.        ",
"          2.2.2.2.2.2.4+5+2.2.2.2.2.2.6+(+7+2.8+;+z.    9+2.2.2.2.2.2.0+;+z.r.a+2.2.;+;+        ",
"          b+c+!+k.k.d+e+(+f+g+h+i+j+4+k+  |+l+m+V.        n+o+p+q+r+s+V.V.r.  t+I.u+V.z.        ",
"                V.V.V.V.;+;+;+;+;+V.V.V.                      z.V.V.V.z.            z.          ",
"                                                                                                ",
"                                                                                                ",
"                                                                                                ",
"                                                                                                "};

#endif
